@@ -140,7 +140,7 @@ class SortedObj(object):
 
     def __init__(self):
         import time
-        self.__created_at__ = time.time() * 10000
+        self.__created_at__ = time.time()
 
     def __lt__(self, other: "SortedObj"):
         return self.__created_at__ < other.__created_at__
@@ -148,6 +148,12 @@ class SortedObj(object):
     def __gt__(self, other: "SortedObj"):
         return self.__created_at__ > other.__created_at__
 
+    def __le__(self, other: "SortedObj"):
+        return self.__created_at__ <= other.__created_at__
+
+    def __ge__(self, other: "SortedObj"):
+        return self.__created_at__ >= other.__created_at__
+
 
 def data_filter(data, key_filter=None, val_filter=None):
     _type_func = {
